/**
 * @file
 * Autocomplete functionality for glossary links.
 */

const $ = jQuery;

/**
 * Override jQuery UI _renderItem function to output HTML by default.
 */
function renderItem(ul, item) {
	const $line = $("<li>").addClass("glossary-autocomplete-item");
	const $wrapper = $("<div>").addClass("glossary-autocomplete-wrapper");
	const $header = $("<div>").addClass("glossary-autocomplete-header");

	// Add language indicator if available (exclude 'und' and 'zxx' for undefined/not applicable languages)
	if (
		Object.prototype.hasOwnProperty.call(item, "langcode") &&
		item.langcode &&
		!["und", "zxx"].includes(item.langcode.toLowerCase())
	) {
		$header.append(
			$("<span>")
				.text(item.langcode.toUpperCase())
				.addClass("glossary-autocomplete-language"),
		);
	}

	$header.append(
		$("<span>").html(item.label).addClass("glossary-autocomplete-label"),
	);

	$wrapper.append($header);

	if (Object.prototype.hasOwnProperty.call(item, "description")) {
		$wrapper.append(
			$("<span>")
				.html(item.description)
				.addClass("glossary-autocomplete-description"),
		);
	}

	return $line.append($wrapper).appendTo(ul);
}

/**
 * Initialize autocomplete on the given element.
 */
export default function initializeAutocomplete(element, settings) {
	const { selectHandler, closeHandler, openHandler } = settings;

	/**
	 * JQuery UI autocomplete source callback.
	 */
	function sourceData(request, response) {
		const term = request.term;

		$.ajax({
			url: `/glossary/autocomplete/${encodeURIComponent(term)}`,
			dataType: "json",
			success: (data) => {
				response(
					data.map((item) => ({
						label: item.label,
						value: item.id,
						description: item.description,
						langcode: item.langcode,
						language_name: item.language_name,
					})),
				);
			},
			error: () => {
				response([]);
			},
		});
	}

	const options = {
		appendTo: element.closest(".ck-labeled-field-view"),
		source: sourceData,
		select: selectHandler,
		focus: () => false,
		close: closeHandler,
		open: openHandler,
		minLength: 2,
	};

	const $auto = $(element).autocomplete(options);

	// Override render methods
	const instance = $auto.data("ui-autocomplete");
	instance._renderItem = renderItem;

	$auto
		.autocomplete("widget")
		.addClass("glossary-ui-autocomplete ck-reset_all-excluded");

	$auto.on("click", () => {
		$auto.autocomplete("search", $auto.val());
	});

	return $auto;
}
