const path = require("node:path");
const webpack = require("webpack");
const TerserPlugin = require("terser-webpack-plugin");

module.exports = {
	mode: "production",
	optimization: {
		minimize: true,
		minimizer: [
			new TerserPlugin({
				terserOptions: {
					format: {
						comments: false,
					},
				},
				test: /\.js(\?.*)?$/i,
				extractComments: false,
			}),
		],
		moduleIds: "named",
	},
	entry: {
		glossaryLink: path.resolve(
			__dirname,
			"js/ckeditor5_plugins/glossaryLink/src/index.js",
		),
	},
	output: {
		path: path.resolve(__dirname, "./js/build"),
		filename: "glossaryLink.js",
		library: ["CKEditor5", "glossaryLink"],
		libraryTarget: "umd",
		libraryExport: "default",
	},
	plugins: [
		new webpack.DllReferencePlugin({
			manifest: require("./node_modules/ckeditor5/build/ckeditor5-dll.manifest.json"),
			scope: "ckeditor5/src",
			name: "CKEditor5.dll",
		}),
	],
	module: {
		rules: [
			{
				test: /\.svg$/,
				use: "raw-loader",
			},
		],
	},
	devtool: false,
};
